pub fn get_local_snapshot_from_remote_type_archive(
snapshot: &RemoteSnapshot,
type_archive: &TypeArchive,
) -> Option<BnString>Expand description
Get the local snapshot associated with a remote snapshot (if it exists) in a Type Archive
pub fn get_local_snapshot_from_remote_type_archive(
snapshot: &RemoteSnapshot,
type_archive: &TypeArchive,
) -> Option<BnString>Get the local snapshot associated with a remote snapshot (if it exists) in a Type Archive