pub fn get_remote_snapshot_from_local_type_archive(
type_archive: &TypeArchive,
snapshot_id: &str,
) -> Option<Ref<RemoteSnapshot>>Expand description
Get the remote snapshot associated with a local snapshot (if it exists) in a Type Archive
pub fn get_remote_snapshot_from_local_type_archive(
type_archive: &TypeArchive,
snapshot_id: &str,
) -> Option<Ref<RemoteSnapshot>>Get the remote snapshot associated with a local snapshot (if it exists) in a Type Archive