RemoteProject

Struct RemoteProject 

pub struct RemoteProject { /* private fields */ }

Implementations

Source

impl RemoteProject

pub fn is_open(&self) -> bool

Determine if the project is open (it needs to be opened before you can access its files)

pub fn open(&self) -> Result<(), ()>

Open the project, allowing various file and folder based apis to work, as well as connecting a core Project

pub fn open_with_progress<F: ProgressCallback>( &self, progress: F, ) -> Result<(), ()>

Open the project, allowing various file and folder based apis to work, as well as connecting a core Project

pub fn close(&self)

Close the project and stop all background operations (e.g. file uploads)

pub fn get_for_local_database( database: &Database, ) -> Result<Option<Ref<Self>>, ()>

Get the Remote Project for a Database

pub fn get_for_binaryview(bv: &BinaryView) -> Result<Option<Ref<Self>>, ()>

Get the Remote Project for a BinaryView

pub fn core_project(&self) -> Result<Ref<Project>, ()>

Get the core Project for the remote project.

NOTE: If the project has not been opened, it will be opened upon calling this.

pub fn remote(&self) -> Result<Ref<Remote>, ()>

Get the owning remote

pub fn url(&self) -> String

Get the URL of the project

pub fn id(&self) -> String

Get the unique ID of the project

pub fn created(&self) -> SystemTime

Created date of the project

pub fn last_modified(&self) -> SystemTime

Last modification of the project

pub fn name(&self) -> String

Displayed name of file

pub fn set_name(&self, name: &str) -> Result<(), ()>

Set the description of the file. You will need to push the file to update the remote version.

pub fn description(&self) -> String

Desciprtion of the file

pub fn set_description(&self, description: &str) -> Result<(), ()>

Set the description of the file. You will need to push the file to update the remote version.

pub fn received_file_count(&self) -> u64

Get the number of files in a project (without needing to pull them first)

pub fn received_folder_count(&self) -> u64

Get the number of folders in a project (without needing to pull them first)

pub fn default_path(&self) -> Result<PathBuf, ()>

Get the default directory path for a remote Project. This is based off the Setting for collaboration.directory, the project’s id, and the project’s remote’s id.

pub fn has_pulled_files(&self) -> bool

If the project has pulled the folders yet

pub fn has_pulled_folders(&self) -> bool

If the project has pulled the folders yet

pub fn has_pulled_group_permissions(&self) -> bool

If the project has pulled the group permissions yet

pub fn has_pulled_user_permissions(&self) -> bool

If the project has pulled the user permissions yet

pub fn is_admin(&self) -> bool

If the currently logged in user is an administrator of the project (and can edit permissions and such for the project).

pub fn files(&self) -> Result<Array<RemoteFile>, ()>

Get the list of files in this project.

NOTE: If the project has not been opened, it will be opened upon calling this. NOTE: If folders have not been pulled, they will be pulled upon calling this. NOTE: If files have not been pulled, they will be pulled upon calling this.

pub fn get_file_by_id(&self, id: &str) -> Result<Option<Ref<RemoteFile>>, ()>

Get a specific File in the Project by its id

NOTE: If the project has not been opened, it will be opened upon calling this. NOTE: If files have not been pulled, they will be pulled upon calling this.

pub fn get_file_by_name( &self, name: &str, ) -> Result<Option<Ref<RemoteFile>>, ()>

Get a specific File in the Project by its name

NOTE: If the project has not been opened, it will be opened upon calling this. NOTE: If files have not been pulled, they will be pulled upon calling this.

pub fn pull_files(&self) -> Result<(), ()>

Pull the list of files from the Remote.

NOTE: If the project has not been opened, it will be opened upon calling this. NOTE: If folders have not been pulled, they will be pulled upon calling this.

pub fn pull_files_with_progress<P: ProgressCallback>( &self, progress: P, ) -> Result<(), ()>

Pull the list of files from the Remote.

NOTE: If the project has not been opened, it will be opened upon calling this. NOTE: If folders have not been pulled, they will be pulled upon calling this.

pub fn create_file( &self, filename: &str, contents: &[u8], name: &str, description: &str, parent_folder: Option<&RemoteFolder>, file_type: RemoteFileType, ) -> Result<Ref<RemoteFile>, ()>

Create a new file on the remote and return a reference to the created file

NOTE: If the project has not been opened, it will be opened upon calling this.

  • filename - File name
  • contents - File contents
  • name - Displayed file name
  • description - File description
  • parent_folder - Folder that will contain the file
  • file_type - Type of File to create
pub fn create_file_with_progress<P>( &self, filename: &str, contents: &[u8], name: &str, description: &str, parent_folder: Option<&RemoteFolder>, file_type: RemoteFileType, progress: P, ) -> Result<Ref<RemoteFile>, ()>

Create a new file on the remote and return a reference to the created file

NOTE: If the project has not been opened, it will be opened upon calling this.

  • filename - File name
  • contents - File contents
  • name - Displayed file name
  • description - File description
  • parent_folder - Folder that will contain the file
  • file_type - Type of File to create
  • progress - Function to call on upload progress updates
pub fn push_file<I>(&self, file: &RemoteFile, extra_fields: I) -> Result<(), ()>
where I: IntoIterator<Item = (String, String)>,

Push an updated File object to the Remote

NOTE: If the project has not been opened, it will be opened upon calling this.

pub fn delete_file(&self, file: &RemoteFile) -> Result<(), ()>

pub fn folders(&self) -> Result<Array<RemoteFolder>, ()>

Get the list of folders in this project.

NOTE: If the project has not been opened, it will be opened upon calling this. NOTE: If folders have not been pulled, they will be pulled upon calling this.

pub fn get_folder_by_id( &self, id: &str, ) -> Result<Option<Ref<RemoteFolder>>, ()>

Get a specific Folder in the Project by its id

NOTE: If the project has not been opened, it will be opened upon calling this. NOTE: If folders have not been pulled, they will be pulled upon calling this.

pub fn pull_folders(&self) -> Result<(), ()>

Pull the list of folders from the Remote.

NOTE: If the project has not been opened, it will be opened upon calling this.

pub fn pull_folders_with_progress<P: ProgressCallback>( &self, progress: P, ) -> Result<(), ()>

Pull the list of folders from the Remote.

NOTE: If the project has not been opened, it will be opened upon calling this.

pub fn create_folder( &self, name: &str, description: &str, parent_folder: Option<&RemoteFolder>, ) -> Result<Ref<RemoteFolder>, ()>

Create a new folder on the remote (and pull it)

NOTE: If the project has not been opened, it will be opened upon calling this.

  • name - Displayed folder name
  • description - Folder description
  • parent - Parent folder (optional)
pub fn create_folder_with_progress<P>( &self, name: &str, description: &str, parent_folder: Option<&RemoteFolder>, progress: P, ) -> Result<Ref<RemoteFolder>, ()>

Create a new folder on the remote (and pull it)

NOTE: If the project has not been opened, it will be opened upon calling this.

  • name - Displayed folder name
  • description - Folder description
  • parent - Parent folder (optional)
  • progress - Function to call on upload progress updates
pub fn push_folder<I>( &self, folder: &RemoteFolder, extra_fields: I, ) -> Result<(), ()>
where I: IntoIterator<Item = (String, String)>,

Push an updated Folder object to the Remote

NOTE: If the project has not been opened, it will be opened upon calling this.

  • folder - Folder object which has been updated
  • extra_fields - Extra HTTP fields to send with the update
pub fn delete_folder(&self, folder: &RemoteFolder) -> Result<(), ()>

Delete a folder from the remote

NOTE: If the project has not been opened, it will be opened upon calling this.

pub fn group_permissions(&self) -> Result<Array<Permission>, ()>

Get the list of group permissions in this project.

NOTE: If group permissions have not been pulled, they will be pulled upon calling this.

pub fn user_permissions(&self) -> Result<Array<Permission>, ()>

Get the list of user permissions in this project.

NOTE: If user permissions have not been pulled, they will be pulled upon calling this.

pub fn get_permission_by_id( &self, id: &str, ) -> Result<Option<Ref<Permission>>, ()>

Get a specific permission in the Project by its id.

NOTE: If group or user permissions have not been pulled, they will be pulled upon calling this.

pub fn pull_group_permissions(&self) -> Result<(), ()>

Pull the list of group permissions from the Remote.

pub fn pull_group_permissions_with_progress<F: ProgressCallback>( &self, progress: F, ) -> Result<(), ()>

Pull the list of group permissions from the Remote.

pub fn pull_user_permissions(&self) -> Result<(), ()>

Pull the list of user permissions from the Remote.

pub fn pull_user_permissions_with_progress<F: ProgressCallback>( &self, progress: F, ) -> Result<(), ()>

Pull the list of user permissions from the Remote.

pub fn create_group_permission( &self, group_id: i64, level: CollaborationPermissionLevel, ) -> Result<Ref<Permission>, ()>

Create a new group permission on the remote (and pull it).

Arguments
  • group_id - Group id
  • level - Permission level
pub fn create_group_permission_with_progress<F: ProgressCallback>( &self, group_id: i64, level: CollaborationPermissionLevel, progress: F, ) -> Result<Ref<Permission>, ()>

Create a new group permission on the remote (and pull it).

Arguments
  • group_id - Group id
  • level - Permission level
  • progress - Function to call for upload progress updates
pub fn create_user_permission( &self, user_id: &str, level: CollaborationPermissionLevel, ) -> Result<Ref<Permission>, ()>

Create a new user permission on the remote (and pull it).

Arguments
  • user_id - User id
  • level - Permission level
pub fn create_user_permission_with_progress<F: ProgressCallback>( &self, user_id: &str, level: CollaborationPermissionLevel, progress: F, ) -> Result<Ref<Permission>, ()>

Create a new user permission on the remote (and pull it).

Arguments
  • user_id - User id
  • level - Permission level
  • progress - The progress callback to call
pub fn push_permission<I>( &self, permission: &Permission, extra_fields: I, ) -> Result<(), ()>
where I: IntoIterator<Item = (String, String)>,

Push project permissions to the remote.

Arguments
  • permission - Permission object which has been updated
  • extra_fields - Extra HTTP fields to send with the update
pub fn delete_permission(&self, permission: &Permission) -> Result<(), ()>

Delete a permission from the remote.

pub fn can_user_view(&self, username: &str) -> bool

Determine if a user is in any of the view/edit/admin groups.

Arguments
  • username - Username of user to check
pub fn can_user_edit(&self, username: &str) -> bool

Determine if a user is in any of the edit/admin groups.

Arguments
  • username - Username of user to check
pub fn can_user_admin(&self, username: &str) -> bool

Determine if a user is in the admin group.

Arguments
  • username - Username of user to check
pub fn default_project_path(&self) -> String

Get the default directory path for a remote Project. This is based off the Setting for collaboration.directory, the project’s id, and the project’s remote’s id.

pub fn upload_database<C>( &self, metadata: &FileMetadata, parent_folder: Option<&RemoteFolder>, name_changeset: C, ) -> Result<Ref<RemoteFile>, ()>
where C: NameChangeset,

Upload a file, with database, to the remote under the given project

  • metadata - Local file with database
  • parent_folder - Optional parent folder in which to place this file
  • name_changeset - Function to call for naming a pushed changeset, if necessary
pub fn upload_database_with_progress<C>( &self, metadata: &FileMetadata, parent_folder: Option<&RemoteFolder>, name_changeset: C, progress_function: impl ProgressCallback, ) -> Result<Ref<RemoteFile>, ()>
where C: NameChangeset,

Upload a file, with database, to the remote under the given project

  • metadata - Local file with database
  • parent_folder - Optional parent folder in which to place this file
  • progress -: Function to call for progress updates
  • name_changeset - Function to call for naming a pushed changeset, if necessary